@@ -3,8 +3,6 @@
 #' Save currently active rgl 3D graph to bitmap format in current orientation
 #' 
 #' 
-#' @importFrom rgl rgl.cur
-#' @importFrom rgl rgl.snapshot
 #' @aliases rgl2bitmap rgl2png
 #' @param file name of output file. Any extension is ignored and added
 #' according to the requested output type. If file already exists it is overwritten.
@@ -16,15 +14,18 @@
 #' @export
 #' 
 rgl2bitmap = function(file = "Rplot", type = c("PNG")) {
+  if ( ! requireNamespace("rgl", quietly = TRUE)) {
+    stop("Package 'rgl' is required for this function. Please install it.")
+  }
   type = toupper(type)
   type = match.arg(type)
   ext = paste0(".", tolower(type))
   file = sub("^(.*)[.].*", "\\1", file)  # remove extension if given
   file = paste0(file, ext)  # add extension
-  if (rgl.cur()==0) stop("No rgl device open to capture plot from")
+  if (rgl::rgl.cur()==0) stop("No rgl device open to capture plot from")
+
+  rgl::rgl.snapshot(file, fmt="png", top=TRUE)
 
-  rgl.snapshot(file, fmt="png", top=TRUE)
-  
   message(paste0("Exported rgl graph as ",file))
   
 }
